@@ -12,11 +12,15 @@
 
 #include "abstractmediaproxymodel.h"
 
+#include <QQmlEngine>
+
 class ELISALIB_EXPORT GridViewProxyModel : public AbstractMediaProxyModel
 {
 
     Q_OBJECT
 
+    QML_ELEMENT
+
 public:
 
     explicit GridViewProxyModel(QObject *parent = nullptr);
@@ -29,7 +33,7 @@ public Q_SLOTS:
 
 protected:
 
-    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
+    [[nodiscard]] bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 
 };
 
